from colorama import init as colorama_init
from colorama import Fore

class Speaker:
    name = "default"

    def __init__(self):
        colorama_init()

    def print_name(self):
        print(f"Hi my name is {Fore.GREEN}{self.name}!")


from .speakers import Mohan
from pathlib import Path
#from raj_mohan.speakers import Mohan

def main():

    Mohan().print_name()
    #with open("names.txt") as f:
    with (Path(__file__).parent / "names.txt").open() as f:
        print(f.read())

if __name__ == "__main__":
    main()